@@ -8,9 +8,10 @@ use warnings;
 
 use base 'Yote::Obj';
 
+# only root may edit any fields. public fields are readable by all.
 sub _check_access {
     my( $self, $account, $write_access, $name ) = @_;
-    return $account->is_root() || ( index( $name, '_' ) != 0 && $write_access == 0 );
+    return ( index( $name, '_' ) != 0 && $write_access == 0 ) || ( $account && $account->is_root() );
 } #_check_access
 
 1;
